Package 'norSTR'

Title: Allele Frequencies for 50 Forensic STR Markers
Description: Allele frequency databases for 50 forensic short tandem repeat (STR) markers, covering Norway and several broader regional populations: Europe, Africa, South America, West Asia, Middle Asia, and East Asia. Developed and maintained for use at the Department of Forensic Sciences, Oslo, Norway.
Authors: Magnus Dehli Vigeland [aut, cre] (ORCID: <https://orcid.org/0000-0002-9134-4962>)
Maintainer: Magnus Dehli Vigeland <[email protected]>
License: MIT + file LICENSE
Version: 0.2.1
Built: 2026-05-21 09:00:52 UTC
Source: https://github.com/magnusdv/norstr

Help Index


African STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the African population.

Usage

africaDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

africaDB[1:2]

East Asian STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the East Asian population.

Usage

eastAsiaDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

eastAsiaDB[1:2]

European STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the European population.

Usage

europeDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

europeDB[1:2]

Built-in linkage map

Description

A map providing the genetic positions (in centiMorgans) of each STR marker featured in this package.

Usage

map50

Format

A data frame with 50 rows and 4 columns: Marker, Chr, cM, Kit.


Common STR marker sets

Description

Lists of autosomal STR markers included in widely-used commercial forensic kits. Sex-determining (e.g. Amelogenin) and non-autosomal markers (e.g. Y markers) are explicitly omitted.

Usage

markerSets

Format

A named list of 6 character vectors of marker names.

Details

Kits included:

  • codis: Expanded CODIS core loci (FBI/NIST), 21 autosomal STR markers.

  • fusion6c: PowerPlex® Fusion 6C (Promega), 23 autosomal markers.

  • globalfiler: GlobalFiler™ PCR Amplification Kit (Applied Biosystems), 21 autosomal markers.

  • hdplex: HDplex STR Kit (Qiagen), 9 autosomal markers.

  • sureid: SureID® 23comp Human STR Identification Kit (Health Gene Technologies), 23 autosomal markers.

  • sureid27: Combined SureID® 23comp and SureID® PathFinder Plus; 26 autosomal markers.

Examples

markerSets$fusion6c

Mid Asian STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the Mid Asian population.

Usage

midAsiaDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

midAsiaDB[1:2]

Norwegian STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the Norwegian population.

Usage

norwayDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

norwayDB[1:2]

South American STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the South American population.

Usage

southAmericaDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

southAmericaDB[1:2]

West Asian STR allele frequency database

Description

Allele frequencies for 50 forensic short tandem repeat (STR) markers covering the West Asian population.

Usage

westAsiaDB

Format

A list of 50 frequency vectors. Each vector is a numeric with sum 1, and uses the allele labels as names.

Department of Forensic Sciences, Oslo University Hospital.

Examples

westAsiaDB[1:2]